function [src,classnum,mixmat] = genSS(chip,gene,red,srcnb,app,NL,stab,pval,fileid,sort)

% genSS -   Source Separation for expression data
%          (based upon FastICA, by Hyv?rinen et al)
%
%  usage:    [src,classnum,mixmat] = 
%                  genSS(chip,gene,red,srcnb,app,NL,stab,pval,fileid,sort)
%
%
% INPUT VARIABLES
% ---------------
% chip:        (float array): ngenes X ncond
%                   contains expression data
% gene:        (char array): column vector of size ngenes
%                   contains gene names
% red:         (integer): positive, less than ncond
%                   value of reduced space dimension
% srcnb:        (integer): positive, less than red
%                   number of independent sources
% app:         (string): values 'defl' or 'symm'
%                   approach used for optimization:
%                   deflation or symmetrized
% NL:          (string): values 'pow3', 'tanh', 'gauss' or 'skew'
%                   nonlinearity
% stab:        (string) Values 'on' or 'off' (default value: 'off'). 
%                   controls wether the program uses the stabilized
%                   version of the algorithm or not.
% pval:        (float): between 0 and 1
%                   p-value for selection of most significant genes
%                   in given independent components.
% fileid:      (string)
%                   name of output file.
% sort:        (string): values 'on' or 'off'
%                   if set to 'on', writes genes in alphabetical
%                   order to output file
%
%
% OUTPUT VARIABLES
% ----------------
% src:          (float array): srcnb X ngenes
%                   estimates for independent components
% classnum:    (cell array)
%                   class numbers
% mixmat:      (float array): ncond X srcnb
%                   mixing matrix
%%%%

% Backup
% ------
GenSSData{1} = red;
GenSSData{2} = srcnb;
GenSSData{3} = app;
GenSSData{4} = NL;
GenSSData{5} = stab;
GenSSData{6} = 1; %nb simulations
GenSSData{7} = 0; % threshold
GenSSData{8} = pval;
GenSSData{9} = fileid;
GenSSData{10} = sort;



% Do source separation
% --------------------
%figure(1);
[src, mixmat, sepmat] = fastica(chip',...
             'lastEig',...
             red,...
             'numOfIC',...
             srcnb,...
             'g',...
             NL,...
             'approach',...
             app,...
             'stabilization',...
             stab,...
             'verbose',...
             'off',...
             'displayMode',...
             'off');



classnum = SrcAn(src,gene,GenSSData);

tmp = size(src); tmp = tmp(1);
counter = ones(1,tmp);
GenSSReport(src,gene, classnum, GenSSData, counter,fileid);

