function m = mutinf(x,y)

% mutinf -   mutual information
%
%  usage:    m = mutinf(x,y)
%
%
% INPUT VARIABLES
% ---------------
% x,y:        (float vectors):
%                  input vectors
%                   
%
%
% OUTPUT VARIABLES
% ----------------
% m:           (float): nrow X nrow
%                   mutual information

n=length(x);

if (n ~= length(y)),
  error('vectors must have the same length');
end;

mu_x = mean(x);
mu_y = mean(y);

p_x = sum(x < mu_x)/n;
q_x = sum(x >= mu_x)/n;
p_y = sum(y < mu_y)/n;
q_y = sum(y >= mu_y)/n;

pi11 = sum((x < mu_x) & (y < mu_y))/n;
pi12 = sum((x < mu_x) & (y >= mu_y))/n;
pi21 = sum((x >= mu_x) & (y < mu_y))/n;
pi22 = sum((x >= mu_x) & (y >= mu_y))/n;

m = pi11 * log2(0.0000001+pi11/p_x/p_y);
m = m + pi12 * log2(0.0000001+pi12/p_x/q_y);
m = m + pi21 * log2(0.0000001+pi21/q_x/p_y);
m = m + pi22 * log2(0.0000001+pi22/q_x/q_y);
